@@ -49,8 +49,12 @@ class hyperion_ng:
 
         # parse led update command
         leds_data = self.parse_led_update(data)
-        loop = asyncio.get_event_loop()
-        loop.create_task(self.led_reciever(leds_data))
+
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+        loop.create_task(
+            self.led_reciever(leds_data)
+        )
 
 
     def parse_led_update(self, data):
